@@ -21,11 +21,19 @@ class Midog96x96(H5Dataset):
                          target_key='label',
                          transform=transform,
                          transform_target=transform_target)
+        
+        self.classes = ['non_mitosis', 'mitosis']
 
     @classmethod
     def from_avocado(cls, sub_set: str = 'train', transform: Optional[Callable] = None, transform_target: Optional[Callable] = None):
         return cls('/data/ldap/histopathologic/processed_read_only/MIDOG_H5/96x96', sub_set, transform, transform_target)
 
+    @staticmethod
+    def normalization_values():
+        # Calculated on the 'train' set
+        mean = [0.7469, 0.5232, 0.6920]
+        std = [0.1831, 0.1996, 0.1736]
+        return mean, std
 
 class Midog224x224(H5Dataset):
     """ 
@@ -42,7 +50,17 @@ class Midog224x224(H5Dataset):
                          target_key='label',
                          transform=transform,
                          transform_target=transform_target)
+        
+        self.classes = ['non_mitosis', 'mitosis']
 
     @classmethod
     def from_avocado(cls, sub_set: str = 'train', transform: Optional[Callable] = None, transform_target: Optional[Callable] = None):
-        return cls('//data/ldap/histopathologic/processed_read_only/MIDOG_H5/224x224', sub_set, transform, transform_target)
+        return cls('/data/ldap/histopathologic/processed_read_only/MIDOG_H5/224x224', sub_set, transform, transform_target)
+
+    @staticmethod
+    def normalization_values():
+        # Calculated on the 'train' set
+        mean = [0.7469, 0.5232, 0.6921]
+        std = [0.1927, 0.2092, 0.1811]
+        return mean, std
+        
\ No newline at end of file
